==> atlassian-user-1.26-sources.jar: com/atlassian/user/impl/ldap/search/page/LDAPListOfGroupsPager.java <==
package com.atlassian.user.impl.ldap.search.page;

import com.atlassian.user.EntityException;
import com.atlassian.user.Group;
import com.atlassian.user.impl.ldap.LDAPEntityFactory;
import com.atlassian.user.impl.ldap.LDAPGroupFactory;
import com.atlassian.user.impl.ldap.repository.LdapContextFactory;
import com.atlassian.user.impl.ldap.search.LDAPPagerInfo;
import org.apache.log4j.Category;

import javax.naming.NamingEnumeration;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.SearchResult;
import java.util.List;

public class LDAPListOfGroupsPager extends LDAPEntityPager
{
    public static final Category log = Category.getInstance(LDAPListOfGroupsPager.class);

    public LDAPListOfGroupsPager(LdapContextFactory contextFactory, LDAPEntityFactory groupFactory, LDAPPagerInfo info)
    {
        super(contextFactory, groupFactory, info);
    }

    protected List preloadSearchResult(SearchResult result, List prefetched) throws EntityException
    {
        try
        {
            Attributes entityAttributes = result.getAttributes();
            Attribute listOfEntitiesAttribute = entityAttributes.get(returningAttributes[0]);

            NamingEnumeration listOfEntitiesEnumeration = listOfEntitiesAttribute.getAll();

            while (listOfEntitiesEnumeration.hasMoreElements())
            {
                String groupDN = (String) listOfEntitiesEnumeration.nextElement();
                log.debug("got group dn '" + groupDN + "' from pager");
                try
                {
                    Group group = ((LDAPGroupFactory) entityFactory).getGroup(groupDN);
                    prefetched.add(group);
                }
                catch (Exception e)
                {
                    log.error("Error converting DN: " + groupDN + " into a group entity.", e);
                }
            }
        }
        catch (Throwable e)
        {
            log.error("Could not covnert search result: " + result + " into a list of groups.", e);
        }

        return prefetched;
    }
}

==> atlassian-user-2.2-sources.jar: com/atlassian/user/impl/ldap/search/page/LDAPListOfGroupsPager.java <==
package com.atlassian.user.impl.ldap.search.page;

import com.atlassian.user.EntityException;
import com.atlassian.user.Group;
import com.atlassian.user.impl.ldap.LDAPEntityFactory;
import com.atlassian.user.impl.ldap.LDAPGroupFactory;
import com.atlassian.user.impl.ldap.properties.LdapSearchProperties;
import com.atlassian.user.impl.ldap.repository.LdapContextFactory;
import com.atlassian.user.impl.ldap.search.LDAPPagerInfo;
import org.apache.log4j.Category;

import javax.naming.NamingEnumeration;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.SearchResult;
import java.util.List;

public class LDAPListOfGroupsPager extends LDAPEntityPager<Group>
{
    public static final Category log = Category.getInstance(LDAPListOfGroupsPager.class);

    public LDAPListOfGroupsPager(LdapSearchProperties searchProperties, LdapContextFactory contextFactory, LDAPEntityFactory<? extends Group> groupFactory, LDAPPagerInfo info)
    {
        super(searchProperties, contextFactory, groupFactory, info);
    }

    protected List<Group> preloadSearchResult(SearchResult result, List<Group> prefetched) throws EntityException
    {
        try
        {
            Attributes entityAttributes = result.getAttributes();
            Attribute listOfEntitiesAttribute = entityAttributes.get(returningAttributes[0]);

            NamingEnumeration listOfEntitiesEnumeration = listOfEntitiesAttribute.getAll();

            while (listOfEntitiesEnumeration.hasMoreElements())
            {
                String groupDN = (String) listOfEntitiesEnumeration.nextElement();
                log.debug("got group dn '" + groupDN + "' from pager");
                try
                {
                    Group group = ((LDAPGroupFactory) entityFactory).getGroup(groupDN);
                    prefetched.add(group);
                }
                catch (Exception e)
                {
                    log.error("Error converting DN: " + groupDN + " into a group entity.", e);
                }
            }
        }
        catch (Throwable e)
        {
            log.error("Could not covnert search result: " + result + " into a list of groups.", e);
        }

        return prefetched;
    }
}
